==> haskell-sbv-7.9-3-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-sbv.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sbv
version: 7.9
id: sbv-7.9-F5DBZoOLGEBIIsEGJp65IN
key: sbv-7.9-F5DBZoOLGEBIIsEGJp65IN
license: BSD-3-Clause
copyright: Levent Erkok, 2010-2018
maintainer: Levent Erkok (erkokl@gmail.com)
author: Levent Erkok
stability: Experimental
homepage: http://leventerkok.github.com/sbv/
synopsis: SMT Based Verification: Symbolic Haskell theorem prover using SMT solving.
description:
    Express properties about Haskell programs and automatically prove them using SMT
    (Satisfiability Modulo Theories) solvers.
    .
    For details, please see: <http://leventerkok.github.com/sbv/>
category: Formal Methods, Theorem Provers, Bit vectors, Symbolic Computation, Math, SMT
abi: 6b3ce338973eef14df1d5fe775c806b1
exposed: True
exposed-modules:
    Data.SBV Data.SBV.Char Data.SBV.Control Data.SBV.Dynamic
    Data.SBV.Internals Data.SBV.RegExp Data.SBV.String
    Data.SBV.Tools.CodeGen Data.SBV.Tools.GenTest
    Data.SBV.Tools.Overflow Data.SBV.Tools.Polynomial
    Data.SBV.Tools.STree
    Documentation.SBV.Examples.BitPrecise.BitTricks
    Documentation.SBV.Examples.BitPrecise.Legato
    Documentation.SBV.Examples.BitPrecise.MergeSort
    Documentation.SBV.Examples.BitPrecise.MultMask
    Documentation.SBV.Examples.BitPrecise.PrefixSum
    Documentation.SBV.Examples.CodeGeneration.AddSub
    Documentation.SBV.Examples.CodeGeneration.CRC_USB5
    Documentation.SBV.Examples.CodeGeneration.Fibonacci
    Documentation.SBV.Examples.CodeGeneration.GCD
    Documentation.SBV.Examples.CodeGeneration.PopulationCount
    Documentation.SBV.Examples.CodeGeneration.Uninterpreted
    Documentation.SBV.Examples.Crypto.AES
    Documentation.SBV.Examples.Crypto.RC4
    Documentation.SBV.Examples.Existentials.CRCPolynomial
    Documentation.SBV.Examples.Existentials.Diophantine
    Documentation.SBV.Examples.Misc.Auxiliary
    Documentation.SBV.Examples.Misc.Enumerate
    Documentation.SBV.Examples.Misc.Floating
    Documentation.SBV.Examples.Misc.ModelExtract
    Documentation.SBV.Examples.Misc.NoDiv0
    Documentation.SBV.Examples.Misc.Polynomials
    Documentation.SBV.Examples.Misc.Word4
    Documentation.SBV.Examples.Optimization.ExtField
    Documentation.SBV.Examples.Optimization.LinearOpt
    Documentation.SBV.Examples.Optimization.Production
    Documentation.SBV.Examples.Optimization.VM
    Documentation.SBV.Examples.Puzzles.Birthday
    Documentation.SBV.Examples.Puzzles.Coins
    Documentation.SBV.Examples.Puzzles.Counts
    Documentation.SBV.Examples.Puzzles.DogCatMouse
    Documentation.SBV.Examples.Puzzles.Euler185
    Documentation.SBV.Examples.Puzzles.Fish
    Documentation.SBV.Examples.Puzzles.HexPuzzle
    Documentation.SBV.Examples.Puzzles.MagicSquare
    Documentation.SBV.Examples.Puzzles.NQueens
    Documentation.SBV.Examples.Puzzles.SendMoreMoney
    Documentation.SBV.Examples.Puzzles.Sudoku
    Documentation.SBV.Examples.Puzzles.U2Bridge
    Documentation.SBV.Examples.Queries.AllSat
    Documentation.SBV.Examples.Queries.CaseSplit
    Documentation.SBV.Examples.Queries.Enums
    Documentation.SBV.Examples.Queries.FourFours
    Documentation.SBV.Examples.Queries.GuessNumber
    Documentation.SBV.Examples.Queries.Interpolants
    Documentation.SBV.Examples.Queries.UnsatCore
    Documentation.SBV.Examples.Strings.RegexCrossword
    Documentation.SBV.Examples.Strings.SQLInjection
    Documentation.SBV.Examples.Uninterpreted.AUF
    Documentation.SBV.Examples.Uninterpreted.Deduce
    Documentation.SBV.Examples.Uninterpreted.Function
    Documentation.SBV.Examples.Uninterpreted.Shannon
    Documentation.SBV.Examples.Uninterpreted.Sort
    Documentation.SBV.Examples.Uninterpreted.UISortAllSat
hidden-modules: Data.SBV.Core.AlgReals Data.SBV.Core.Concrete
                Data.SBV.Core.Data Data.SBV.Core.Kind Data.SBV.Core.Model
                Data.SBV.Core.Operations Data.SBV.Core.Floating
                Data.SBV.Core.Splittable Data.SBV.Core.Symbolic
                Data.SBV.Control.Query Data.SBV.Control.Types
                Data.SBV.Control.Utils Data.SBV.Compilers.C
                Data.SBV.Compilers.CodeGen Data.SBV.SMT.SMT Data.SBV.SMT.SMTLib
                Data.SBV.SMT.SMTLib2 Data.SBV.SMT.SMTLibNames Data.SBV.SMT.Utils
                Data.SBV.Provers.Prover Data.SBV.Provers.Boolector
                Data.SBV.Provers.CVC4 Data.SBV.Provers.Yices Data.SBV.Provers.Z3
                Data.SBV.Provers.MathSAT Data.SBV.Provers.ABC
                Data.SBV.Utils.Boolean Data.SBV.Utils.Numeric Data.SBV.Utils.TDiff
                Data.SBV.Utils.Lib Data.SBV.Utils.PrettyNum Data.SBV.Utils.SExpr
import-dirs: /usr/lib/ghc-8.4.3/site-local/sbv-7.9
library-dirs: /usr/lib/ghc-8.4.3/site-local/sbv-7.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/sbv-7.9
hs-libraries: HSsbv-7.9-F5DBZoOLGEBIIsEGJp65IN
depends:
    base-4.11.1.0 ghc-8.4.3 QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    crackNum-2.0-HmfOyQpofo0ESDsNG4d2dR template-haskell-2.13.0.0
    array-0.5.2.0 async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    containers-0.5.11.0 deepseq-1.4.3.0 directory-1.3.1.5
    filepath-1.4.2 time-1.8.0.2 pretty-1.1.3.6 process-1.6.3.0
    mtl-2.2.2 random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    syb-0.7-2jW43lwzJV5e7EQvU8PxV
    data-binary-ieee754-0.4.4-GMEnBfyxjqq6rJmTySXper
    generic-deriving-1.12.1-H7lQD1Y7ggDCKFR27XQal3
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-8.4.3=b85a78185b88bdae88410d8ef8f69684
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             crackNum-2.0-HmfOyQpofo0ESDsNG4d2dR=dd7c6332d7185176e6ed6be8aceee292
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             data-binary-ieee754-0.4.4-GMEnBfyxjqq6rJmTySXper=d66971a5e33e6c01a2e11481d8e08c1d
             generic-deriving-1.12.1-H7lQD1Y7ggDCKFR27XQal3=11a1807b319a1333ef4071dbf6b6aee0
haddock-interfaces: /usr/share/doc/haskell-sbv/html/sbv.haddock
haddock-html: /usr/share/doc/haskell-sbv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-sbv-7.9-5-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-sbv.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: sbv
version: 7.9
id: sbv-7.9-1zEvKJarais9sltW5NMR1s
key: sbv-7.9-1zEvKJarais9sltW5NMR1s
license: BSD-3-Clause
copyright: Levent Erkok, 2010-2018
maintainer: Levent Erkok (erkokl@gmail.com)
author: Levent Erkok
stability: Experimental
homepage: http://leventerkok.github.com/sbv/
synopsis: SMT Based Verification: Symbolic Haskell theorem prover using SMT solving.
description:
    Express properties about Haskell programs and automatically prove them using SMT
    (Satisfiability Modulo Theories) solvers.
    .
    For details, please see: <http://leventerkok.github.com/sbv/>
category: Formal Methods, Theorem Provers, Bit vectors, Symbolic Computation, Math, SMT
abi: 3940d47d346bc1594c78720efb4163ad
exposed: True
exposed-modules:
    Data.SBV Data.SBV.Char Data.SBV.Control Data.SBV.Dynamic
    Data.SBV.Internals Data.SBV.RegExp Data.SBV.String
    Data.SBV.Tools.CodeGen Data.SBV.Tools.GenTest
    Data.SBV.Tools.Overflow Data.SBV.Tools.Polynomial
    Data.SBV.Tools.STree
    Documentation.SBV.Examples.BitPrecise.BitTricks
    Documentation.SBV.Examples.BitPrecise.Legato
    Documentation.SBV.Examples.BitPrecise.MergeSort
    Documentation.SBV.Examples.BitPrecise.MultMask
    Documentation.SBV.Examples.BitPrecise.PrefixSum
    Documentation.SBV.Examples.CodeGeneration.AddSub
    Documentation.SBV.Examples.CodeGeneration.CRC_USB5
    Documentation.SBV.Examples.CodeGeneration.Fibonacci
    Documentation.SBV.Examples.CodeGeneration.GCD
    Documentation.SBV.Examples.CodeGeneration.PopulationCount
    Documentation.SBV.Examples.CodeGeneration.Uninterpreted
    Documentation.SBV.Examples.Crypto.AES
    Documentation.SBV.Examples.Crypto.RC4
    Documentation.SBV.Examples.Existentials.CRCPolynomial
    Documentation.SBV.Examples.Existentials.Diophantine
    Documentation.SBV.Examples.Misc.Auxiliary
    Documentation.SBV.Examples.Misc.Enumerate
    Documentation.SBV.Examples.Misc.Floating
    Documentation.SBV.Examples.Misc.ModelExtract
    Documentation.SBV.Examples.Misc.NoDiv0
    Documentation.SBV.Examples.Misc.Polynomials
    Documentation.SBV.Examples.Misc.Word4
    Documentation.SBV.Examples.Optimization.ExtField
    Documentation.SBV.Examples.Optimization.LinearOpt
    Documentation.SBV.Examples.Optimization.Production
    Documentation.SBV.Examples.Optimization.VM
    Documentation.SBV.Examples.Puzzles.Birthday
    Documentation.SBV.Examples.Puzzles.Coins
    Documentation.SBV.Examples.Puzzles.Counts
    Documentation.SBV.Examples.Puzzles.DogCatMouse
    Documentation.SBV.Examples.Puzzles.Euler185
    Documentation.SBV.Examples.Puzzles.Fish
    Documentation.SBV.Examples.Puzzles.HexPuzzle
    Documentation.SBV.Examples.Puzzles.MagicSquare
    Documentation.SBV.Examples.Puzzles.NQueens
    Documentation.SBV.Examples.Puzzles.SendMoreMoney
    Documentation.SBV.Examples.Puzzles.Sudoku
    Documentation.SBV.Examples.Puzzles.U2Bridge
    Documentation.SBV.Examples.Queries.AllSat
    Documentation.SBV.Examples.Queries.CaseSplit
    Documentation.SBV.Examples.Queries.Enums
    Documentation.SBV.Examples.Queries.FourFours
    Documentation.SBV.Examples.Queries.GuessNumber
    Documentation.SBV.Examples.Queries.Interpolants
    Documentation.SBV.Examples.Queries.UnsatCore
    Documentation.SBV.Examples.Strings.RegexCrossword
    Documentation.SBV.Examples.Strings.SQLInjection
    Documentation.SBV.Examples.Uninterpreted.AUF
    Documentation.SBV.Examples.Uninterpreted.Deduce
    Documentation.SBV.Examples.Uninterpreted.Function
    Documentation.SBV.Examples.Uninterpreted.Shannon
    Documentation.SBV.Examples.Uninterpreted.Sort
    Documentation.SBV.Examples.Uninterpreted.UISortAllSat
hidden-modules: Data.SBV.Core.AlgReals Data.SBV.Core.Concrete
                Data.SBV.Core.Data Data.SBV.Core.Kind Data.SBV.Core.Model
                Data.SBV.Core.Operations Data.SBV.Core.Floating
                Data.SBV.Core.Splittable Data.SBV.Core.Symbolic
                Data.SBV.Control.Query Data.SBV.Control.Types
                Data.SBV.Control.Utils Data.SBV.Compilers.C
                Data.SBV.Compilers.CodeGen Data.SBV.SMT.SMT Data.SBV.SMT.SMTLib
                Data.SBV.SMT.SMTLib2 Data.SBV.SMT.SMTLibNames Data.SBV.SMT.Utils
                Data.SBV.Provers.Prover Data.SBV.Provers.Boolector
                Data.SBV.Provers.CVC4 Data.SBV.Provers.Yices Data.SBV.Provers.Z3
                Data.SBV.Provers.MathSAT Data.SBV.Provers.ABC
                Data.SBV.Utils.Boolean Data.SBV.Utils.Numeric Data.SBV.Utils.TDiff
                Data.SBV.Utils.Lib Data.SBV.Utils.PrettyNum Data.SBV.Utils.SExpr
import-dirs: /usr/lib/ghc-8.4.3/site-local/sbv-7.9
library-dirs: /usr/lib/ghc-8.4.3/site-local/sbv-7.9
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.4.3/sbv-7.9
hs-libraries: HSsbv-7.9-1zEvKJarais9sltW5NMR1s
depends:
    base-4.11.1.0 ghc-8.4.3 QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr
    crackNum-2.0-HmfOyQpofo0ESDsNG4d2dR template-haskell-2.13.0.0
    array-0.5.2.0 async-2.2.1-B6m2kYywRJu7nicgTBxsJe
    containers-0.5.11.0 deepseq-1.4.3.0 directory-1.3.1.5
    filepath-1.4.2 time-1.8.0.2 pretty-1.1.3.6 process-1.6.3.0
    mtl-2.2.2 random-1.1-9LLJAJa4iQFLJiLXBOBXBV
    syb-0.7-2jW43lwzJV5e7EQvU8PxV
    data-binary-ieee754-0.4.4-GMEnBfyxjqq6rJmTySXper
    generic-deriving-1.12.1-H7lQD1Y7ggDCKFR27XQal3
abi-depends: base-4.11.1.0=a3fb1645bafaa89172454c2eea8dfdc9
             ghc-8.4.3=b85a78185b88bdae88410d8ef8f69684
             QuickCheck-2.11.3-58QsvdIMmwDDNaUIIDmLAr=59a035869ce3bae16d8c8360447f600f
             crackNum-2.0-HmfOyQpofo0ESDsNG4d2dR=dd7c6332d7185176e6ed6be8aceee292
             template-haskell-2.13.0.0=ac7dfd04924d4ebfa90a119ad22a36cc
             array-0.5.2.0=dc85b03ee806d784249cc791da6109c3
             async-2.2.1-B6m2kYywRJu7nicgTBxsJe=32776142fda961cc693aa4db742773f9
             containers-0.5.11.0=94bb4831ae701bd40855b2dc2d65cf7c
             deepseq-1.4.3.0=34da2d42d10eacba0aad99c95b538637
             directory-1.3.1.5=f5fa3aef63d61d9b32ef25d211ef137f
             filepath-1.4.2=2408ba322304c0a06810db2d7363214a
             time-1.8.0.2=042930fb6746cbaf3bc794f817f8a6b2
             pretty-1.1.3.6=3c31686bd534e1773b954ae82713db97
             process-1.6.3.0=b58285e21ceee9f67d7be28ddb8b2627
             mtl-2.2.2=0b3b35c3b96c7607606ed10087c4aa4a
             random-1.1-9LLJAJa4iQFLJiLXBOBXBV=2cade9e72fa19fe7a43e5ace84505d9f
             syb-0.7-2jW43lwzJV5e7EQvU8PxV=867165047495b4e6f144c8b9b108f918
             data-binary-ieee754-0.4.4-GMEnBfyxjqq6rJmTySXper=d66971a5e33e6c01a2e11481d8e08c1d
             generic-deriving-1.12.1-H7lQD1Y7ggDCKFR27XQal3=11a1807b319a1333ef4071dbf6b6aee0
haddock-interfaces: /usr/share/doc/haskell-sbv/html/sbv.haddock
haddock-html: /usr/share/doc/haskell-sbv/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
